Nester_pre
==========

The nester_pre is an open source Python library for nested data processing.
It lets you print nested data out screen or a file.

Installation
------------
Nester_pre is hosted on PyPI_ and GitHub_.

Install Nester_pre from PyPI
****************************

Install Nester_pre from PyPI_ for lastest version: ::

    $ sudo pip install nester_pre
	
If you don't have pip, execute ::	

    $ sudo apt-get install python-pip

to install pip on Debian-base Linux distribution.

Download and Install manually pip_.

Get Nester_pre from GitHub
**************************

To follow the lastest version of Nester_pre, use ::
    
	$ git clone https://github.com/immark/nester_pre.git
	
to clone Nester_pre repository, or download manually from GitHub_.

.. _GitHub:
    https://github.com/immark/nester_pre

.. _PyPI:
    https://pypi.python.org/pypi/nester_pre

.. _pip:
    https://pip.pypa.io/en/stable/installing/
